@@ -51,7 +51,7 @@ def generate_configs(env, user):
     if version.parse(mls_v) > version.parse("2020.8.29"):
         from sktmls import MLSRuntimeENV
 
-        return [{**config, "runtime_env": r} for r in MLSRuntimeENV.list_items()]
+        return [{**config, "runtime_env": r} for r in MLSRuntimeENV.list_items() if r != MLSRuntimeENV.EDD]
 
     return [config]
 
