@@ -63,7 +63,6 @@ def get_spark(scale=0, queue=None):
 
     tmp_uuid = str(uuid.uuid4())
     app_name = f"skt-{os.environ.get('USER', 'default')}-{tmp_uuid}"
-    os.environ["ARROW_PRE_0_15_IPC_FORMAT"] = "1"
 
     key = get_secrets("gcp/sktaic-datahub/dataflow")["config"]
     key_file_name = tempfile.mkstemp()[1]
@@ -83,6 +82,11 @@ def get_spark(scale=0, queue=None):
         else "hdfs:///jars/spark-bigquery-with-dependencies_2.11-0.17.3.jar"
     )
 
+    arrow_enabled = "spark.sql.execution.arrow.pyspark.enabled" if is_spark_3 else "spark.sql.execution.arrow.enabled"
+
+    arrow_pre_ipc_format = "0" if is_spark_3 else "1"
+    os.environ["ARROW_PRE_0_15_IPC_FORMAT"] = arrow_pre_ipc_format
+
     if queue == "nrt":
         spark = (
             SparkSession.builder.config("spark.app.name", app_name)
@@ -96,8 +100,8 @@ def get_spark(scale=0, queue=None):
             .config("spark.yarn.queue", queue)
             .config("spark.ui.enabled", "false")
             .config("spark.port.maxRetries", "128")
-            .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
-            .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+            .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
+            .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
             .config(
                 "spark.jars",
                 bigquery_jars,
@@ -105,7 +109,7 @@ def get_spark(scale=0, queue=None):
             .enableHiveSupport()
             .getOrCreate()
         )
-        spark.conf.set("spark.sql.execution.arrow.enabled", "true")
+        spark.conf.set(arrow_enabled, "true")
         return spark
 
     if scale in [1, 2, 3, 4]:
@@ -119,8 +123,8 @@ def get_spark(scale=0, queue=None):
             .config("spark.yarn.queue", queue)
             .config("spark.ui.enabled", "false")
             .config("spark.port.maxRetries", "128")
-            .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
-            .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+            .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
+            .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
             .config(
                 "spark.jars",
                 bigquery_jars,
@@ -139,8 +143,8 @@ def get_spark(scale=0, queue=None):
             .config("spark.yarn.queue", queue)
             .config("spark.ui.enabled", "false")
             .config("spark.port.maxRetries", "128")
-            .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
-            .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+            .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
+            .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
             .config(
                 "spark.jars",
                 bigquery_jars,
@@ -160,8 +164,8 @@ def get_spark(scale=0, queue=None):
                 .config("spark.yarn.queue", queue)
                 .config("spark.ui.enabled", "false")
                 .config("spark.port.maxRetries", "128")
-                .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
-                .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+                .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
+                .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
                 .config(
                     "spark.jars",
                     bigquery_jars,
@@ -182,8 +186,8 @@ def get_spark(scale=0, queue=None):
                 .config("spark.yarn.queue", queue)
                 .config("spark.ui.enabled", "false")
                 .config("spark.port.maxRetries", "128")
-                .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
-                .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+                .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
+                .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", arrow_pre_ipc_format)
                 .config(
                     "spark.jars",
                     bigquery_jars,
@@ -191,7 +195,7 @@ def get_spark(scale=0, queue=None):
                 .enableHiveSupport()
                 .getOrCreate()
             )
-    spark.conf.set("spark.sql.execution.arrow.enabled", "true")
+    spark.conf.set(arrow_enabled, "true")
     return spark
 
 
